@@ -3,6 +3,7 @@ from typing import Any
 from typing_extensions import override
 
 from openai._utils import LazyProxy
+from openai._extras._common import MissingDependencyError
 
 
 class RecursiveLazyProxy(LazyProxy[Any]):
@@ -21,3 +22,14 @@ def test_recursive_proxy() -> None:
     assert dir(proxy) == []
     assert type(proxy).__name__ == "RecursiveLazyProxy"
     assert type(operator.attrgetter("name.foo.bar.baz")(proxy)).__name__ == "RecursiveLazyProxy"
+
+
+def test_isinstance_does_not_error() -> None:
+    class MissingDepsProxy(LazyProxy[Any]):
+        @override
+        def __load__(self) -> Any:
+            raise MissingDependencyError("Mocking missing dependency")
+
+    proxy = MissingDepsProxy()
+    assert not isinstance(proxy, dict)
+    assert isinstance(proxy, LazyProxy)
